import pandas as pd
import numpy as np
from scipy.signal import savgol_filter
from scipy.signal import argrelextrema
import matplotlib.pyplot as plt
import os

def chair_values(SpineShoulder_Y,ShoulderLeft_Y,ShoulderRight_Y, ktime, frame_inc, frame_change, inc_plano, directory, dict_silla, dict_inc, plot=False, save_fig=False):
	if os.path.exists(directory+'/weight.csv') is True:
		silla=pd.read_csv(directory+'/weight.csv')
		silla=silla[silla.columns[0]].tolist()
		silla=savgol_filter(silla,41,8)

		
		def peso_silla(data):
			val=[]
			c=0
			for i in data:
				if i>10 and data[c+5]>10:
					val.append(i)
			counts = np.bincount(val)
			peso_medio=np.argmax(counts)
			if plot==True:
				plt.plot(np.arange(0,len(silla))/80, silla)
				plt.ylabel('Peso / Kg')
				plt.xlabel('tiempo / s')
				plt.grid(True)
				plt.title('Silla Báscula')
				if save_fig==True:
					plt.savefig(directory+'/data_info/silla/total.png')
				else:
					plt.show()
				plt.close()

			dict_silla['Peso / Kg']=int(peso_medio)
			
			return(peso_medio)
			
		peso=peso_silla(silla)
		
		frame_inc_begin=0
		def IncBegin(data):
			maxs=argrelextrema(data, np.greater)[0]
			maxs_fit=[]
			for i in maxs:
				if i<frame_inc*(8/3) and data[i]>20:
					maxs_fit.append(i)
			global frame_inc_begin
			frame_inc_begin=maxs_fit[-1]
			return(frame_inc_begin) 
		
		#global frame_inc_begin
		frame_inc_begin=IncBegin(silla)
		
		
		def Suavidad(lista):
			
			mins=argrelextrema(lista, np.less)[0]
			
			special_mins=[]
			for i in mins:
				if lista[i]<peso*0.6:
					special_mins.append(lista[i])
			mins_fit=[]
			for i in mins:
				if lista[i]<peso*0.9:
					mins_fit.append(lista[i])
		
			if len(special_mins)>0: #si hay algún mínimo especial, la suavidad se reduce a la mitad
				g=0.5
			else:
				g=1
				
			lista2=[]
			for i in mins_fit:
				lista2.append(peso-i)   # Damos mas peso a mayor amplitud del minimo
			if len(lista2)==0:
				s=1
			else:
				if len(lista2)>=11:
					s=0
				else:
					k=sum(lista2)/(peso*(len(lista2))) #Valor <1 proporcional a la amplitud de los minimos
					coef_range=np.linspace(1,1/k,10)
					s=1-k*coef_range[len(lista2)-1] #Suavidad rango [0,1]
			
			dict_inc['Suavidad (S)']=round(s*g,2)
			
		Suavidad(silla[0:frame_inc_begin])
		
		seg_change=ktime[frame_change]
		silla_frame_change=int(seg_change*80)
		
		def Percusion(data):
			p=1-(peso/max(data))
			
			dict_silla['Percusion (P)']=round(p,2)

		Percusion(silla[int(len(silla)/2):])
		
		def Fuerza(silla, frame_inc, peso):
			dist=[]
			a=[]
			b=[]
			c=[]
			for i in np.arange(frame_inc+30, frame_inc+45):
				a.append(SpineShoulder_Y[i])
				b.append(ShoulderRight_Y[i])
				c.append(ShoulderLeft_Y[i])
					
			a=np.nanmean(a)
			b=np.nanmean(b)
			c=np.nanmean(c)
			x=[]
			y=[]
			z=[]
			
			for i in np.arange(0, int(frame_inc_begin*(3/8))):
				x.append(SpineShoulder_Y[i])
				y.append(ShoulderRight_Y[i])
				z.append(ShoulderLeft_Y[i])
			x=np.nanmean(x)
			y=np.nanmean(y)
			z=np.nanmean(z)
			dist=[a-x,b-y,c-z]
		
			dist_med=np.mean(dist)+(np.mean(dist)*np.sin(np.deg2rad(inc_plano)))
			tiempo=(frame_inc/30 - frame_inc_begin/80)
			
			f=(peso*dist_med)/(tiempo*tiempo)
			
			dict_inc['Altura recorrida / m']=round(dist_med,2)
			dict_inc['Fuerza (F) / N']=round(f,2)
			dict_inc['Tiempo / s']=round(tiempo,2)
		
		Fuerza(silla, frame_inc, peso)
		
		def plot_silla_values(silla):
			plt.plot(np.arange(0,silla_frame_change)/80, silla[0:silla_frame_change])
			plt.axvline((frame_inc_begin/80),color='k')
			plt.ylabel('Peso / Kg')
			plt.xlabel('tiempo / s')
			plt.grid(True)
			plt.title('Silla Báscula')
			if save_fig==True:
				plt.savefig(directory+'/data_info/incorporacion/inc.png')
			else:
				plt.show()
			plt.close()
			
			ind=int(frame_sentada*(8/3))
			#print('ind',ind)
			#print(silla[ind:])
			
			#print(np.arange(silla[ind], len(silla[ind:])))
			
			
			#x=(np.arange(silla[ind], len(silla[ind:]))+ind)/80
			#x=(np.arange(len(silla[ind:]))+ind)/80
			#plt.plot(x,silla[ind:])
			
			x=(np.arange(len(silla[silla_frame_change:])))+silla_frame_change
			plt.plot(x/80,silla[silla_frame_change:])
			plt.ylabel('Peso / Kg')
			plt.xlabel('tiempo (aproximado)/ s')
			plt.grid(True)
			plt.title('Silla Báscula')
			if save_fig==True:
				plt.savefig(directory+'/data_info/silla/sent2.png')
			else:
				plt.show()
			plt.close()
		
		if plot==True:
			plot_silla_values(silla)

	else: 
		frame_inc_begin=0
		
	return(frame_inc_begin)


import numpy as np

def angulo_brazo(ShoulderRight_Z_arr,ElbowRight_Z_arr,ShoulderRight_Y_arr,ElbowRight_Y_arr,ShoulderLeft_Z_arr,ElbowLeft_Z_arr,ShoulderLeft_Y_arr,ElbowLeft_Y_arr,WristRight_Z_arr,WristLeft_Z_arr,WristRight_Y_arr,WristLeft_Y_arr):
	  #derecha     
	z1=ShoulderRight_Z_arr-ElbowRight_Z_arr
	y1=ShoulderRight_Y_arr-ElbowRight_Y_arr
	
	z2=WristRight_Z_arr-ElbowRight_Z_arr
	y2=WristRight_Y_arr-ElbowRight_Y_arr
	cos_alpha=(z1*z2 + y1*y2)/ (np.sqrt(z1*z1 + y1*y1) * np.sqrt(z2*z2 + y2*y2))
	list_ang_dcha=np.arccos(cos_alpha)*57.29
	#izquierda
	z1=ShoulderLeft_Z_arr-ElbowLeft_Z_arr
	y1=ShoulderLeft_Y_arr-ElbowLeft_Y_arr
	
	z2=WristLeft_Z_arr-ElbowLeft_Z_arr
	y2=WristLeft_Y_arr-ElbowLeft_Y_arr
	cos_alpha=(z1*z2 + y1*y2)/ (np.sqrt(z1*z1 + y1*y1) * np.sqrt(z2*z2 + y2*y2))
	list_ang_izq=np.arccos(cos_alpha)*57.29
	
	return(list_ang_dcha, list_ang_izq)
	

def angulo_pierna(HipRight_Z_arr,KneeRight_Z_arr,AnkleRight_Z_arr,HipRight_Y_arr,KneeRight_Y_arr,AnkleRight_Y_arr,HipLeft_Z_arr,KneeLeft_Z_arr,AnkleLeft_Z_arr,HipLeft_Y_arr,KneeLeft_Y_arr,AnkleLeft_Y_arr):
	#derecha
	z1=HipRight_Z_arr-KneeRight_Z_arr
	y1=HipRight_Y_arr-KneeRight_Y_arr
	
	z2=AnkleRight_Z_arr-KneeRight_Z_arr
	y2=AnkleRight_Y_arr-KneeRight_Y_arr
	cos_alpha=(z1*z2 + y1*y2)/ (np.sqrt(z1*z1 + y1*y1) * np.sqrt(z2*z2 + y2*y2))
	list_ang_dcha=np.arccos(cos_alpha)*57.29
	#izquierda
	z1=HipLeft_Z_arr-KneeLeft_Z_arr
	y1=HipLeft_Y_arr-KneeLeft_Y_arr
	
	z2=AnkleLeft_Z_arr-KneeLeft_Z_arr
	y2=AnkleLeft_Y_arr-KneeLeft_Y_arr
	cos_alpha=(z1*z2 + y1*y2)/ (np.sqrt(z1*z1 + y1*y1) * np.sqrt(z2*z2 + y2*y2))
	list_ang_izq=np.arccos(cos_alpha)*57.29

	return(list_ang_dcha, list_ang_izq)

	
def ang_pierna_tronco(KneeRight_Z_arr,HipRight_Z_arr,SpineBase_Z_arr,KneeRight_Y_arr,HipRight_Y_arr,SpineBase_Y_arr,KneeLeft_Y_arr,HipLeft_Y_arr,KneeLeft_Z_arr,HipLeft_Z_arr,SpineShoulder_Z_arr,SpineShoulder_Y_arr):
	
	#derecha
	z1=KneeRight_Z_arr-HipRight_Z_arr
	y1=KneeRight_Y_arr-HipRight_Y_arr
	dif_cadera_z=SpineBase_Z_arr-HipRight_Z_arr
	dif_cadera_y=SpineBase_Y_arr-HipRight_Y_arr
	spineshoulder_z=SpineShoulder_Z_arr-dif_cadera_z
	spineshoulder_y=SpineShoulder_Y_arr-dif_cadera_y
	
	z2=spineshoulder_z-HipRight_Z_arr
	y2=spineshoulder_y-HipRight_Y_arr
	
	cos_alpha=(z1*z2 + y1*y2)/ (np.sqrt(z1*z1 + y1*y1) * np.sqrt(z2*z2 + y2*y2))
	list_ang_pdcha=np.arccos(cos_alpha)*57.29
	
	#izquierda
	z1=KneeLeft_Z_arr-HipLeft_Z_arr
	y1=KneeLeft_Y_arr-HipLeft_Y_arr
	dif_cadera_z=SpineBase_Z_arr-HipLeft_Z_arr
	dif_cadera_y=SpineBase_Y_arr-HipLeft_Y_arr
	spineshoulder_z=SpineShoulder_Z_arr-dif_cadera_z
	spineshoulder_y=SpineShoulder_Y_arr-dif_cadera_y
	
	z2=spineshoulder_z-HipLeft_Z_arr
	y2=spineshoulder_y-HipLeft_Y_arr
	
	cos_alpha=(z1*z2 + y1*y2)/ (np.sqrt(z1*z1 + y1*y1) * np.sqrt(z2*z2 + y2*y2))
	list_ang_pizq=np.arccos(cos_alpha)*57.29
	
	return(list_ang_pdcha,list_ang_pizq)

def inclinacion_tronco(SpineShoulder_Z_arr,SpineBase_Z_arr,SpineShoulder_Y_arr,SpineBase_Y_arr):
                
	z=SpineBase_Z_arr-SpineShoulder_Z_arr
	y=SpineShoulder_Y_arr - SpineBase_Y_arr
	list_ang=np.arctan(z/y).round(2)*57.29
	
	return (list_ang)


import numpy as np
from scipy.signal import argrelextrema
from scipy.signal import savgol_filter
import pandas as pd


def SinglePoint(iterable): #elimina valores duplicados y adyacentes
	lista=[]
	prev = object()
	for item in iterable:
		if item != prev and item != np.nan:
			prev = item
			lista.append(item)
			
	return(lista)


def change_nans(l1,l2): #intercala los nans de una lista entre los valores de otra en la misma posición
	l=[]
	c=-1
	for i in l1:
		if np.isnan(i):
			l.append(i)
		else:
			c+=1
			l.append(l2[c])
	return(l)
	
def Smooth(data,g): #suaviza las curvas aunque tengan valores nans, analiza todos los datos no nans en conjunto
	data=np.asarray(data)
	data_nans=data[~ np.isnan(data)]
	window=41
	if len(data_nans)<window and len(data_nans)%2==0:
		window=len(data_nans)-1
	elif len(data_nans)<window and len(data_nans)%2!=0:
		window=len(data_nans)
	data_filter=savgol_filter(data_nans,window,g)
	data_fit=[]
	c=-1
	for i in data:
		if np.isnan(i):
			data_fit.append(i)
		else:
			c+=1
			data_fit.append(data_filter[c])
	return(data_fit)
	
			
def Maximos(data):#función para encontrar máximos en iterables que contengan nans y que requieren suavizado
	if isinstance(data,list):
		pass
	else:
		data=data.tolist()
		
	data_arr=np.asarray(data)
	data_nan=data_arr[~np.isnan(data_arr)]
	window=41
	if len(data_nan)<window and len(data_nan)%2==0:
		window=len(data_nan)-1
	elif len(data_nan)<window and len(data_nan)%2!=0:
		window=len(data_nan)
		
	data_filter=savgol_filter(data_nan,window,9)
	maximos=argrelextrema(data_filter, np.greater_equal)[0]
	maximos_fit=[]
	for i in maximos:
		maximos_fit.append(data.index(data_nan[i]))

	if maximos_fit[-1]==data.index(data_nan[-1]):
		maximos_fit=maximos_fit[:-1]    

	if maximos_fit[0]==0:
		maximos_fit=maximos_fit[1:]


	return(maximos_fit)
	
def Minimos(data):#función para encontrar mínimos en iterables que contengan nans y que requieren suavizado
	if isinstance(data,list):
		pass
	else:
		data=data.tolist()
		
	data_arr=np.asarray(data)
	data_nan=data_arr[~np.isnan(data_arr)]
	
	window=41
	if len(data_nan)<window and len(data_nan)%2==0:
		window=len(data_nan)-1
	elif len(data_nan)<window and len(data_nan)%2!=0:
		window=len(data_nan)
	print('window',window)
	if window>9:
		data_filter=savgol_filter(data_nan,window,9)
	else:
		data_filter=savgol_filter(data_nan,window,window-1)
	
	minimos=argrelextrema(data_filter, np.less_equal)[0]
	minimos_fit=[]
	for i in minimos:
		minimos_fit.append(data.index(data_nan[i]))

	if minimos_fit[-1]==data.index(data_nan[-1]):
		minimos_fit=minimos_fit[:-1]    

	if minimos_fit[0]==0:
		minimos_fit=minimos_fit[1:]

	return(minimos_fit)

def CountMax2(data,umbral):  #Máximos a partir de un umbral
	index=Maximos(data)
	values=[]
	for i in index:
		values.append(data[i])
	max_abs=np.max(values)
	index_umbral=[]
	for i in index:
		if data[i]>=max_abs*umbral:
			index_umbral.append(i)
	first_max=index_umbral[0]
	return(first_max)
	
def CountMax(data):
	values=SinglePoint(data)
	maxvalue=[]

	for i in values:
		if (i > np.nanmax(values)*0.95):
			maxvalue.append(i)

	return(maxvalue)
	
def frame_firstmax_lists(data1, data2): #busca el primer máximo para cada lista y hace la media

	max_1=CountMax(data1)
	max_2=CountMax(data2)
	values_1=np.where(data1 == max_1[0])
	values_2=np.where(data2 == max_2[0])

	frame=int((values_1[0]+values_2[0])/2)

	return(frame)
	
def mean_std(data_x, data_y): 
	#data_x: lista de listas con range(0,100) en la que faltan números intermedios
	#data_y: lista de listas con el valor de la función para cada x
	#Busca las x que faltan e interpola el valor de las y para cada lista
	#Genera una lista con las medias de los valores de data_y y otra con sus desviaciones típicas
    y_list_norm=[]
    for n,y in enumerate(data_y):
        y_norm=[]
        c=0
        k=0
        for j in np.arange(101):
            if c in data_x[n]:
                y_norm.append(y[k])
                k+=1
            else:
                y_norm.append(np.nan)
            c+=1
        y_norm=pd.Series(y_norm).interpolate(method='polynomial', order=2).tolist()
        y_list_norm.append(y_norm)
        
    mean=np.nanmean(np.array(y_list_norm), axis=0)
    std=np.nanstd(np.array(y_list_norm), axis=0)
    return(mean,std)


import json, codecs

def SaveDictToJson(directory,dict_marcha,dict_inc,dict_tec,dict_silla, dict_paso):
	#convierte los diccionarios en archivos json 
	with codecs.open(directory+'/data_info/marcha/tracking_results.json', 'w', 'utf8') as f:
		 f.write(json.dumps(dict_marcha, sort_keys = False, ensure_ascii=False))
	with codecs.open(directory+'/data_info/incorporacion/gettingup_results.json', 'w', 'utf8') as f:
		 f.write(json.dumps(dict_inc, sort_keys = False, ensure_ascii=False))
	with codecs.open(directory+'/data_info/tecnics_results.json', 'w', 'utf8') as f:
		 f.write(json.dumps(dict_tec, sort_keys = False, ensure_ascii=False))
	with codecs.open(directory+'/data_info/silla/silla_results.json', 'w', 'utf8') as f:
		 f.write(json.dumps(dict_silla, sort_keys = False, ensure_ascii=False))
	with codecs.open(directory+'/data_info/paso/gait_results.json', 'w', 'utf8') as f:
		 f.write(json.dumps(dict_paso, sort_keys = False, ensure_ascii=False))


import pandas as pd
import numpy as np
from scipy.signal import argrelextrema
import matplotlib.pyplot as plt
from .utils import SinglePoint, Smooth, mean_std


def steps_index(KneeLeft_Z,KneeRight_Z,list_ang_pdcha,list_ang_pizq, ktime, frame_change, frame_inc):
	#busca los frames en los que empieza y termina cada paso con cada pierna
	#lo hace utilizando primero la distancia de cada rodilla a la cámara
	#y después la forma del ángulo de la rodilla
	n=2
	slice_= lambda A, n=n: [A[i:i+n] for i in range(0, len(A), n)]

	ci=pd.Series(KneeLeft_Z).interpolate(method='polynomial', order=2).tolist()
	cd=pd.Series(KneeRight_Z).interpolate(method='polynomial', order=2).tolist()
	ci=np.asarray(ci)
	cd=np.asarray(cd)
	ktime_arr=np.asarray(ktime)
	s_list_ang_pdcha=Smooth(pd.Series(list_ang_pdcha[:frame_change]).interpolate(method='polynomial', order=2).tolist(),10)
	s_list_ang_pizq=Smooth(pd.Series(list_ang_pizq[:frame_change]).interpolate(method='polynomial', order=2).tolist(),10)
	
	first_nan_izq=np.where(np.isnan(np.array(s_list_ang_pizq)))[0][0]
	first_nan_dcha=np.where(np.isnan(np.array(s_list_ang_pdcha)))[0][0]

	idx_total = np.argwhere(np.diff(np.sign(cd - ci))).flatten()
	idx=[]
	for i in idx_total:
		if i>frame_inc-15 and i<frame_change:
			idx.append(i)
			

	idx_slice1=slice_(idx)
	idx_slice2=slice_(idx[1:])

	idx_slice1=[i for i in idx_slice1 if len(i)>1]
	idx_slice2=[i for i in idx_slice2 if len(i)>1]

	idx_slice1_fit=[i for i in idx_slice1 if i[1]-i[0]>2]
	idx_slice2_fit=[i for i in idx_slice2 if i[1]-i[0]>2]

	idx1=[j for i in idx_slice1_fit for j in i]
	idx2=[j for i in idx_slice2_fit for j in i]
	idx=np.sort(idx1+idx2)
	idx=SinglePoint(idx)

	sign_first_leg=np.mean(cd[idx_slice1_fit[0][0]+1:idx_slice1_fit[0][1]]-ci[idx_slice1_fit[0][0]+1:idx_slice1_fit[0][1]])
	if sign_first_leg<0:
		pierna_izq=[idx_slice1_fit,s_list_ang_pizq]
		pierna_dcha=[idx_slice2_fit,s_list_ang_pdcha]
	else:
		pierna_izq=[idx_slice2_fit,s_list_ang_pizq]
		pierna_dcha=[idx_slice1_fit,s_list_ang_pdcha]

	pierna_izq[0]=[i for i in pierna_izq[0] if i[0]<first_nan_izq ]
	pierna_dcha[0]=[i for i in pierna_dcha[0] if i[0]<first_nan_dcha ]
	
	value_max_idx_slice_izq=[]
	ind_max_idx_slice_izq=[]
	value_max_idx_slice_dcha=[]
	ind_max_idx_slice_dcha=[]
	for i in pierna_izq[0]:
		if len(i)>1 and i[1]-i[0]>2:
			l=pierna_izq[1][i[0]:i[1]]
			val=np.nanmax(l)
			m=argrelextrema(np.array(l),np.greater)[0]
			l2=[l[i] for i in m]
			#if len(l2)==0 and i==pierna_izq[0][-1]:
			if i==pierna_izq[0][-1]:
				if len(l2)==0:
					l2=[j for j in l if 160<j<=180]
				else:
					l2=[j for j in l2 if 160<j<=180]
			try:
				val2=l2[0]
				if np.isnan(val)==False:
					value_max_idx_slice_izq.append(val2)
					ind_max_idx_slice_izq.append(list(l).index(val2)+i[0])
			except:pass
			
	for i in pierna_dcha[0]:
		if len(i)>1 and i[1]-i[0]>2:
			l=pierna_dcha[1][i[0]:i[1]]
			val=np.nanmax(l)
			m=argrelextrema(np.array(l),np.greater)[0]
			l2=[l[i] for i in m]
			#if len(l2)==0 and i==pierna_dcha[0][-1]:
			#	l2=[j for j in l if 160<j<=180]
			if i==pierna_dcha[0][-1]:
				if len(l2)==0:
					l2=[j for j in l if 160<j<=180]
				else:
					l2=[j for j in l2 if 160<j<=180]
			try:
				val2=np.nanmax(l2)
				if np.isnan(val)==False:
					value_max_idx_slice_dcha.append(val2)
					ind_max_idx_slice_dcha.append(list(l).index(val2)+i[0])
			except:pass
	
	n=2
	slice_2= lambda A, n=n: [A[i:i+n] for i in range(0, len(A), 1) if len(A[i:i+n])==2]
	steps_izq=slice_2(ind_max_idx_slice_izq)
	steps_dcha=slice_2(ind_max_idx_slice_dcha)
	
	return(steps_izq, steps_dcha)

'''
def steps_info(AnkleLeft_Z,AnkleRight_Z, frame_change,steps_izq, steps_dcha, ktime,dict_marcha):
	steps_izq_times=[ktime[i[1]]-ktime[i[0]] for i in steps_izq]
	steps_dcha_times=[ktime[i[1]]-ktime[i[0]] for i in steps_dcha]
	mean_time_steps_izq=np.nanmean(steps_izq_times)
	mean_time_steps_dcha=np.nanmean(steps_dcha_times)
	
	ankly=Smooth(pd.Series(AnkleLeft_Z[:frame_change]).interpolate(method='polynomial', order=2).tolist(),10)
	ankry=Smooth(pd.Series(AnkleRight_Z[:frame_change]).interpolate(method='polynomial', order=2).tolist(),10)
	steps_izq_len=[ankly[i[0]]-ankly[i[1]] for i in steps_izq]
	steps_dcha_len=[ankry[i[0]]-ankry[i[1]] for i in steps_dcha]
	mean_len_steps_izq=np.nanmean(steps_izq_len)
	mean_len_steps_dcha=np.nanmean(steps_dcha_len)
	
	cadencia=(len(steps_izq)+len(steps_dcha))/((mean_time_steps_izq*len(steps_izq) + mean_time_steps_dcha*len(steps_dcha))/60)
	dict_marcha['Numero pasos pierna izquierda']= len(steps_izq)*2
	dict_marcha['Numero pasos pierna derecha']= len(steps_dcha)*2
	dict_marcha['Tiempo medio zancada izquierda  /s']= round(mean_time_steps_izq,2)
	dict_marcha['Tiempo medio zancada derecha  /s']= round(mean_time_steps_dcha,2)
	dict_marcha['Distancia media zancada izquierda  /m']= round(mean_len_steps_izq,2)
	dict_marcha['Distancia media zancada derecha  /m']= round(mean_len_steps_dcha,2)
	dict_marcha['Cadencia estimada de la marcha  / pasos/min']= int(cadencia)*2
		
	return(len(steps_izq),len(steps_dcha),mean_time_steps_izq,mean_time_steps_dcha,mean_len_steps_izq,mean_len_steps_dcha)
'''
def steps_info(KneeLeft_Z,KneeRight_Z,AnkleLeft_Z,AnkleRight_Z, frame_inc, frame_change, ktime,dict_marcha):
	n=2
	slice_2= lambda A, n=n: [A[i:i+n] for i in range(0, len(A), 1) if len(A[i:i+n])==2]
	slice_= lambda A, n=n: [A[i:i+n] for i in range(0, len(A), n)]
	ci=pd.Series(KneeLeft_Z).interpolate(method='polynomial', order=2).tolist()
	cd=pd.Series(KneeRight_Z).interpolate(method='polynomial', order=2).tolist()
	ci=np.asarray(ci)
	cd=np.asarray(cd)
	ktime_arr=np.asarray(ktime)
	idx_total = np.argwhere(np.diff(np.sign(cd - ci))).flatten()
	idx=[]
	for i in idx_total:
		if i>frame_inc-15 and i<frame_change:
			idx.append(i)
	idx_slice1=slice_(idx)
	idx_slice2=slice_(idx[1:])
	idx_slice1_fit=[i for i in idx_slice1 if (len(i)>1 and i[1]-i[0]>2)]
	idx_slice2_fit=[i for i in idx_slice2 if (len(i)>1 and i[1]-i[0]>2)]
	idx1=[j for i in idx_slice1_fit for j in i]
	idx2=[j for i in idx_slice2_fit for j in i]
	idx=np.sort(idx1+idx2)
	idx=SinglePoint(idx)
	
	sign_first_leg=np.mean(cd[idx_slice1_fit[0][0]+1:idx_slice1_fit[0][1]]-ci[idx_slice1_fit[0][0]+1:idx_slice1_fit[0][1]])
	if sign_first_leg<0:
		first_leg='dcha'
	else:
		first_leg='izq'
	
	if first_leg=='izq':
		idx_stride_izq=[i for n,i in enumerate(idx) if n%2==0]
		idx_stride_dcha=[i for n,i in enumerate(idx) if n%2!=0]
	else:
		idx_stride_dcha=[i for n,i in enumerate(idx) if n%2==0]
		idx_stride_izq=[i for n,i in enumerate(idx) if n%2!=0]
		
		
	idx_stride_izq_slice=slice_2(idx_stride_izq)
	idx_stride_dcha_slice=slice_2(idx_stride_dcha)
	times_izq=[ktime[i[1]]-ktime[i[0]] for i in idx_stride_izq_slice]
	times_dcha=[ktime[i[1]]-ktime[i[0]] for i in idx_stride_dcha_slice]
	len_izq=[AnkleLeft_Z[i[0]]-AnkleLeft_Z[i[1]] for i in idx_stride_izq_slice]
	len_dcha=[AnkleRight_Z[i[0]]-AnkleRight_Z[i[1]] for i in idx_stride_izq_slice]
	
	n_ciclos=(len(idx_stride_izq_slice)+len(idx_stride_dcha_slice))
	
	cadencia=(n_ciclos*2)/((np.mean([np.nanmean(times_dcha),np.nanmean(times_izq)])*(2*n_ciclos))/60)
	
	
	dict_marcha['Numero zancadas/ciclos pierna izquierda']= len(idx_stride_izq_slice)
	dict_marcha['Numero zancadas/ciclos pierna derecha']= len(idx_stride_dcha_slice)
	dict_marcha['Tiempo medio zancada/ciclo pierna izquierda  /s']= round(np.nanmean(times_izq),2)
	dict_marcha['Tiempo medio zancada/ciclo pierna derecha  /s']= round(np.nanmean(times_dcha),2)
	dict_marcha['Distancia media zancada/ciclo pierna izquierda  /m']= round(np.nanmean(len_izq),2)
	dict_marcha['Distancia media zancada/ciclo pierna derecha  /m']= round(np.nanmean(len_dcha),2)
	dict_marcha['Cadencia estimada de la marcha  / pasos/min']= int(cadencia)*2
	
	return(n_ciclos)
	
def steps_index2(AnkleLeft_Z,AnkleRight_Z, frame_inc, frame_change):
	n=2
	slice_= lambda A, n=n: [A[i:i+n] for i in range(0, len(A), n)]
	slice_2= lambda A, n=n: [A[i:i+n] for i in range(0, len(A), 1) if len(A[i:i+n])==2]
	ankly=np.array(Smooth(pd.Series(AnkleLeft_Z[:frame_change]).interpolate(method='polynomial', order=2).tolist(),6))
	ankry=np.array(Smooth(pd.Series(AnkleRight_Z[:frame_change]).interpolate(method='polynomial', order=2).tolist(),6))
	l=ankly[frame_inc:]-ankry[frame_inc:]
	maxs=argrelextrema(l,np.greater)[0]
	mins=argrelextrema(l,np.less)[0]
	maxs_values=[l[i] for i in maxs]
	if maxs_values[-1]<0.9*np.nanmean(maxs_values):
		maxs=maxs[:-1]
	maxs=[i+frame_inc for i in maxs]
	mins=[i+frame_inc for i in mins]
	maxs=slice_2(maxs)
	mins=slice_2(mins)
	maxs=[i for i in maxs if len(i)>1]
	mins=[i for i in mins if len(i)>1]
	steps_izq=maxs
	steps_dcha=mins
	
	return(steps_izq, steps_dcha)
	
	
	
def knee_angles_gait(frame_change,list_ang_pdcha,list_ang_pizq, ktime, steps_izq, steps_dcha, directory, dict_paso, save_fig=False):
	s_list_ang_pdcha=Smooth(pd.Series(list_ang_pdcha[:frame_change]).interpolate(method='polynomial', order=2).tolist(),10)
	s_list_ang_pizq=Smooth(pd.Series(list_ang_pizq[:frame_change]).interpolate(method='polynomial', order=2).tolist(),10)
	s_list_ang_pdcha_invert=np.abs(180-np.array(s_list_ang_pdcha))
	s_list_ang_pizq_invert=np.abs(180-np.array(s_list_ang_pizq))

	
	steps_1=[]
	x_list_int_izq=[]
	for step in steps_izq:
		data=s_list_ang_pizq_invert[step[0]:step[1]]
		x=np.linspace(0,100,len(ktime[step[0]:step[1]]))
		x_int=[int(i) for i in x]
		x_list_int_izq.append(x_int)
		steps_1.append(data)

	
	steps_2=[]
	x_list_int_dcha=[]
	for step in steps_dcha:
		data=s_list_ang_pdcha_invert[step[0]:step[1]]
		x=np.linspace(0,100,len(ktime[step[0]:step[1]]))
		x_int=[int(i) for i in x]
		x_list_int_dcha.append(x_int)
		steps_2.append(data)

	x=np.arange(101)
	pierna_dcha=mean_std(x_list_int_dcha, steps_2)
	pierna_izq=mean_std(x_list_int_izq, steps_1)
	
	fig, axs = plt.subplots(1, 2, figsize=(14,3))
	fig.suptitle('Ángulos de la Rodilla \n', fontsize=14)
	axs[0].plot(x, pierna_dcha[0],label='Rodilla_dcha')
	axs[0].fill_between(x,pierna_dcha[0]-pierna_dcha[1], pierna_dcha[0]+pierna_dcha[1], alpha=0.1, color='blue')
	axs[0].grid(True)
	axs[1].plot(x, pierna_izq[0],label='Rodilla_izq')
	axs[1].grid(True)
	axs[1].fill_between(x,pierna_izq[0]-pierna_izq[1], pierna_izq[0]+pierna_izq[1], alpha=0.1, color='blue')
	axs[1].legend()
	axs[0].legend()
	axs[0].set_xlabel('\n% Ciclo Pierna DERECHA (n={})'.format(len(steps_dcha)), fontsize=14)
	axs[1].set_xlabel('\n% Ciclo Pierna IZQUIERDA (n={})'.format(len(steps_izq)), fontsize=14)
	axs[1].set_ylabel('Ángulo rodilla /deg')
	axs[0].set_ylabel('Ángulo rodilla /deg')
	if save_fig==True:
		plt.savefig(directory+'/data_info/paso/knee_angles_gait.png',bbox_inches = 'tight')
	else:
		plt.show()
	plt.close()
	max_angle_izq=np.nanmax(pierna_izq[0])
	max_angle_dcha=np.nanmax(pierna_dcha[0])
	
	dict_paso['Angulo flexion rodilla izquierda /deg']= round(max_angle_izq,2)
	dict_paso['Angulo flexion rodilla derecha /deg']= round(max_angle_dcha,2)
	
	return(max_angle_izq,max_angle_dcha)
	
def InfoCads(HipLeft_X,HipLeft_Y,HipLeft_Z,HipRight_X,HipRight_Y,HipRight_Z, list_ang_tronco, ktime, steps_izq, steps_dcha,directory, save_fig=False):
	#Busca los ángulos de la cadera en cada paso en función de los frames encontrados con steps_index()
		 
	ci_x_fit=Smooth(HipLeft_X,6)
	ci_y_fit=Smooth(HipLeft_Y,6)
	ci_z_fit=Smooth(HipLeft_Z,6)
	cd_x_fit=Smooth(HipRight_X,6)
	cd_y_fit=Smooth(HipRight_Y,6)
	cd_z_fit=Smooth(HipRight_Z,6)

	 #OBLICUIDAD
	ci_x_arr=np.asarray(ci_x_fit)
	ci_y_arr=np.asarray(ci_y_fit)
	cd_x_arr=np.asarray(cd_x_fit)
	cd_y_arr=np.asarray(cd_y_fit)
	dif_cadera_x=ci_x_arr-cd_x_arr
	dif_cadera_y=ci_y_arr-cd_y_arr

	tan_alpha=dif_cadera_y/dif_cadera_x
	alpha=np.rad2deg(np.arctan(tan_alpha))

	#ROTACION
	ci_z_arr=np.asarray(ci_z_fit)
	cd_z_arr=np.asarray(cd_z_fit)

	dif_cadera_z=ci_z_arr-cd_z_arr

	tan_alpha_rot=dif_cadera_z/dif_cadera_x
	alpha_rot=np.rad2deg(np.arctan(tan_alpha_rot))

	######################matriz figuras###########################################
	if len(steps_izq)>4:
		steps_izq_cut=steps_izq[1:-1]
	elif len(steps_izq)>3:
		steps_izq_cut=steps_izq[1:]
	else:
		steps_izq_cut=steps_izq
		
	if len(steps_dcha)>4:
		steps_dcha_cut=steps_dcha[1:-1]
	elif len(steps_dcha)>3:
		steps_dcha_cut=steps_dcha[1:]
	else:
		steps_dcha_cut=steps_dcha
		
	steps_ang_tronco_izq=[]
	steps_rot_izq=[]
	steps_ob_izq=[]
	x_list_int_izq=[]


	for n,step in enumerate(steps_izq_cut):
		y1=Smooth(list_ang_tronco[step[0]:step[1]],6)
		y2=alpha_rot[step[0]:step[1]]
		y3=alpha[step[0]:step[1]]
		x=np.linspace(0,100,len(ktime[step[0]:step[1]]))
		x_int=[int(i) for i in x]
		steps_ang_tronco_izq.append(y1)
		steps_rot_izq.append(y2)
		steps_ob_izq.append(y3)
		x_list_int_izq.append(x_int)

	steps_ang_tronco_dcha=[]
	steps_rot_dcha=[]
	steps_ob_dcha=[]
	x_list_int_dcha=[]
	for n,step in enumerate(steps_dcha_cut):
		y1=Smooth(list_ang_tronco[step[0]:step[1]],6)
		y2=alpha_rot[step[0]:step[1]]
		y3=alpha[step[0]:step[1]]
		x=np.linspace(0,100,len(ktime[step[0]:step[1]]))
		x_int=[int(i) for i in x]
		steps_ang_tronco_dcha.append(y1)
		steps_rot_dcha.append(y2)
		steps_ob_dcha.append(y3)
		x_list_int_dcha.append(x_int)
		  

	fig, axs = plt.subplots(3, 2, figsize=(12,5))
	fig.tight_layout(rect=[0, 0, 1, 0.9]) 
	fig.suptitle('Ángulos de la Cadera', fontsize=14)
	x=np.arange(101)

	tronco_izq=mean_std(x_list_int_izq, steps_ang_tronco_izq)
	rot_izq=mean_std(x_list_int_izq, steps_rot_izq)
	ob_izq=mean_std(x_list_int_izq, steps_ob_izq)

	axs[0, 1].plot(x, tronco_izq[0], label='{} Ciclo'.format(n))
	axs[0, 1].fill_between(x,tronco_izq[0]-tronco_izq[1], tronco_izq[0]+tronco_izq[1], alpha=0.1, color='blue')
	axs[1, 1].plot(x, rot_izq[0],label='{} Ciclo'.format(n))
	axs[1, 1].fill_between(x,rot_izq[0]-rot_izq[1], rot_izq[0]+rot_izq[1], alpha=0.1, color='blue')
	axs[2, 1].plot(x,ob_izq[0],label='{} Ciclo'.format(n))
	axs[2, 1].fill_between(x,ob_izq[0]-ob_izq[1], ob_izq[0]+ob_izq[1], alpha=0.1, color='blue')
	axs[0, 1].set_title('INCLINACIÓN COLUMNA')
	axs[0, 1].grid(True)
	axs[0, 1].axhline(0, color='black')
		
	axs[1, 1].set_title('ROTACIÓN')
	axs[1, 1].grid(True)
	axs[1, 1].axhline(0, color='black')
		
	axs[2, 1].set_title('OBLICUIDAD')
	axs[2, 1].grid(True)
	axs[2, 1].axhline(0, color='black')
	axs[2, 1].set_xlabel('\n% Ciclo Pierna IZQUIERDA (n={})'.format(len(steps_izq_cut)), fontsize=14)


	tronco_dcha=mean_std(x_list_int_dcha, steps_ang_tronco_dcha)
	rot_dcha=mean_std(x_list_int_dcha, steps_rot_dcha)
	ob_dcha=mean_std(x_list_int_dcha, steps_ob_dcha)

	axs[0, 0].plot(x, tronco_dcha[0], label='{} Ciclo'.format(n))
	axs[0, 0].fill_between(x,tronco_dcha[0]-tronco_dcha[1], tronco_dcha[0]+tronco_dcha[1], alpha=0.1, color='blue')
	axs[1, 0].plot(x, rot_dcha[0],label='{} Ciclo'.format(n))
	axs[1, 0].fill_between(x,rot_dcha[0]-rot_dcha[1], rot_dcha[0]+rot_dcha[1], alpha=0.1, color='blue')
	axs[2, 0].plot(x,ob_dcha[0],label='{} Ciclo'.format(n))
	axs[2, 0].fill_between(x,ob_dcha[0]-ob_dcha[1], ob_dcha[0]+ob_dcha[1], alpha=0.1, color='blue')
	axs[0, 0].set_title('INCLINACIÓN COLUMNA')
	axs[0, 0].grid(True)
	axs[0, 0].axhline(0, color='black')

	axs[1, 0].set_title('ROTACIÓN')
	axs[1, 0].grid(True)
	axs[1, 0].axhline(0, color='black')

	axs[2, 0].set_title('OBLICUIDAD')
	axs[2, 0].grid(True)
	axs[2, 0].axhline(0, color='black')
	axs[2, 0].set_xlabel('\n% Ciclo Pierna DERECHA (n={})'.format(len(steps_dcha_cut)), fontsize=14)

	if save_fig==True:
		plt.savefig(directory+'/data_info/paso/hip_angles_gait.png',bbox_inches = 'tight')
	else:
		plt.show()
	plt.close()





import io
from json2html import *
import json
import os

def HtmlGenerator(directory):
	#genera un archivo html con toda la informacion del test
	f = io.open(directory+'/data.html','w', encoding="utf-8")
	
	with open(directory+'/data_info/marcha/tracking_results.json') as data_file_tr:
		tr_rs = json.loads(data_file_tr.read())
	with open(directory+'/data_info/incorporacion/gettingup_results.json') as data_file_inc:
		inc_rs = json.loads(data_file_inc.read())
	with open(directory+'/data_info/tecnics_results.json') as data_file_tec:
		tec_rs = json.loads(data_file_tec.read())
	with open(directory+'/data_info/silla/silla_results.json') as data_file_silla:
		silla_rs = json.loads(data_file_silla.read())
	with open(directory+'/data_info/paso/gait_results.json') as data_file_paso:
		paso_rs = json.loads(data_file_paso.read())
		
	a=json2html.convert(json=tr_rs)
	b=json2html.convert(json=inc_rs)
	c=json2html.convert(json=silla_rs)
	d=json2html.convert(json=paso_rs)
	e=json2html.convert(json=tec_rs)

	
	message = """
	<html>
	<head>
	<title>Datos procesados</title>
	<p style="text-align:center;"><img src='"""+os.getcwd()+"""\\logo3.png' alt="Logo"></p>
	<br/><br/>
	<p style="text-align:center;"><img src="data_info\\fases.png" alt="fases"></p>
	<br/><br/><button class="accordion">DATOS SOBRE LA MARCHA ADELANTE</button>
	<div class="panel">
	<br/><br/>
	"""+a+"""<br>
		
	<input type="submit" id="Map" value="Mostrar graficas" onclick="showImg()"/>
	<input type="submit" id="Map" value="Ocultar graficas" onclick="hideImg()"/><br>
	
	<img id="map_img1" src="data_info\marcha\\vel_inst.png" style="display:;"/><br>
	<img id="map_img2" src="data_info\marcha\\shoulder_angles.png" style="display:;"/><br>
	<img id="map_img3" src="data_info\marcha\\knee_angles.png" style="display:;"/><br>
	<img id="map_img4" src="data_info\marcha\\spine_angles.png" style="display:;"/><br>
	<img id="map_img5" src="data_info\marcha\\elbow_mov.png" style="display:;"/><br>
	<br/><br/>
	</div>
	<button class="accordion">DATOS SOBRE LA INCORPORACION</button>
	<div class="panel">
	<br/><br/>
	"""+b+"""<br>
	<input type="submit" id="Map" value="Mostrar graficas" onclick="showImg1()"/>
	<input type="submit" id="Map" value="Ocultar graficas" onclick="hideImg1()"/><br>
	
	<img id="map_img11" src="data_info\incorporacion\\spine_legs_angles.png" style="display:;"/><br>
	<img id="map_img12" src="data_info\incorporacion\\spine_angles.png" style="display:;"/><br>
	<img id="map_img13" src="data_info\incorporacion\\knee_angles.png" style="display:;"/><br>
	<img id="map_img14" src="data_info\silla\\chair_inc.png" style="display:;"/><br>
	<br/><br/>
	</div>
	
	<button class="accordion">DATOS SOBRE LA SENTADA</button>
	
	<div class="panel">
	<br/><br/>
	"""+c+"""<br>
	<input type="submit" id="Map" value="Mostrar graficas" onclick="showImg2()"/>
	<input type="submit" id="Map" value="Ocultar graficas" onclick="hideImg2()"/><br>
	
	<img id="map_img15" src="data_info\silla\\knee_angles.png" style="display:;"/><br>
	<img id="map_img16" src="data_info\silla\\chair_sent.png" style="display:;"/><br>
	<br/><br/>
	
	</div>
	
	<button class="accordion">DATOS POR CICLO DE PIERNA</button>
	
	<div class="panel">
	<br/><br/>
	"""+d+"""<br>
	<input type="submit" id="Map" value="Mostrar graficas" onclick="showImg3()"/>
	<input type="submit" id="Map" value="Ocultar graficas" onclick="hideImg3()"/><br>
	
	<img id="map_img18" src="data_info\paso\\knee_angles_gait.png" style="display:;"/><br>
	<br/><br/><br/>
	<img id="map_img19" src="data_info\paso\\hip_angles_gait.png" style="display:;"/><br>
	<br/><br/>
	
	</div>
	
	<button class="accordion">DATOS TECNICOS</button>
	
	<div class="panel">
	<br/><br/>
	"""+e+"""<br>
		
	
	</div><br/><br/>
	
	<style>
	
	.accordion {
	
	  background-color: #eee;
	  color: #444;
	  cursor: pointer;
	  padding: 18px;
	  width: 100%;
	  border: none;
	  text-align: left;
	  outline: none;
	  font-size: 15px;
	  transition: 0.4s;
	  font-weight: bold;
	}
	
	.active,
	.accordion:hover {
	  background-color: #ccc;
	}
	
	.accordion:after {
	
	  content: "+";
	  color: #777;
	  font-weight: bold;
	  float: right;
	  margin-left: 5px;
	
	}
	.active:after {
	
	  content: "-";
	
	}
	
	.panel {
	
	  padding: 0 18px;
	  background-color: white;
	  max-height: 0;
	  overflow: hidden;
	  transition: max-height 0.2s ease-out;
	
	}
	
	table {
	  font-family: arial, sans-serif;
	  border-collapse: collapse;
	  width: 50%;
	}
	td, th {
	  border: 1px solid #dddddd;
	  text-align: left;
	  padding: 8px;
	}
	
	tr:nth-child(even) {
	  background-color: #dddddd;
	}
	</style>
	
	<script>
	
	var acc = document.getElementsByClassName("accordion");
	
	  var i;
	
	  for (i = 0; i < acc.length; i++) {
		acc[i].addEventListener("click", function() {
		  this.classList.toggle("active");
		  var panel = this.nextElementSibling;
		  if (panel.style.maxHeight) {
			panel.style.maxHeight = null;
		  } else {
			panel.style.maxHeight = panel.scrollHeight + "px";
		  }
		});
	  }
	
	function showImg() {
		document.getElementById("map_img1").style.display = "";
		document.getElementById("map_img2").style.display = "";
		document.getElementById("map_img3").style.display = "";
		document.getElementById("map_img4").style.display = "";
		document.getElementById("map_img5").style.display = "";
	}
	function hideImg() {
		document.getElementById("map_img1").style.display = "none";
		document.getElementById("map_img2").style.display = "none";
		document.getElementById("map_img3").style.display = "none";
		document.getElementById("map_img4").style.display = "none";
		document.getElementById("map_img5").style.display = "none";
	}
	 function showImg1() {
		document.getElementById("map_img11").style.display = "";
		document.getElementById("map_img12").style.display = "";
		document.getElementById("map_img13").style.display = "";
		document.getElementById("map_img14").style.display = "";
	}
	function hideImg1() {
		document.getElementById("map_img11").style.display = "none";
		document.getElementById("map_img12").style.display = "none";
		document.getElementById("map_img13").style.display = "none";
		document.getElementById("map_img14").style.display = "none";
	}
	function showImg2() {
		document.getElementById("map_img15").style.display = "";
		document.getElementById("map_img16").style.display = "";
	}
	function hideImg2() {
		document.getElementById("map_img15").style.display = "none";
		document.getElementById("map_img16").style.display = "none";
		document.getElementById("map_img17").style.display = "none";
	}
	function showImg3() {
		document.getElementById("map_img18").style.display = "";
		document.getElementById("map_img19").style.display = "";
	}
	function hideImg3() {
		document.getElementById("map_img18").style.display = "none";
		document.getElementById("map_img19").style.display = "none";
	}
	
	</script>
	</html>"""
	
	f.write(message)
	f.close()


import matplotlib.pyplot as plt
import pandas as pd
import numpy as np
import os
from .utils import Smooth
from scipy.signal import savgol_filter

def knee_angles(ktime,list_ang_pizq, list_ang_pdcha, frame_init, frame_end, directory, save_fig=False, phase='marcha'):
	angizq=Smooth(pd.Series(list_ang_pizq[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	angdcha=Smooth(pd.Series(list_ang_pdcha[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	x=ktime[frame_init:frame_end]
	plt.figure(figsize=(16,5))
	plt.plot(x, angizq, label='rodilla_izq')
	plt.plot(x, angdcha, label='rodilla_dcha')
	plt.grid(True)
	plt.legend()
	plt.xlabel('tiempo /s')
	plt.ylabel('Angulo rodilla /deg')
	plt.title('Angulo de las rodillas')
	if save_fig==True:
		if phase=='marcha':
			plt.savefig(directory+'/data_info/marcha/knee_angles.png')
		if phase=='inc':
			plt.savefig(directory+'/data_info/incorporacion/knee_angles.png')
		if phase=='sent':
			plt.savefig(directory+'/data_info/silla/knee_angles.png')
	else:
		plt.show()
	plt.close()

def elbow_angles(ktime,list_ang_bizq, list_ang_bdcho, frame_init, frame_end,directory, save_fig=False, phase='marcha'):
	angizq=Smooth(pd.Series(list_ang_bizq[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	angdcho=Smooth(pd.Series(list_ang_bdcho[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	x=ktime[frame_init:frame_end]
	plt.figure(figsize=(16,5))
	plt.plot(x, angizq, label='codo_izq')
	plt.plot(x, angdcho, label='codo_dcho')
	plt.grid(True)
	plt.legend()
	plt.xlabel('tiempo /s')
	plt.ylabel('Angulo codo /deg')
	plt.title('Angulo de los codos')
	if save_fig==True:
		if phase=='marcha':
			plt.savefig(directory+'/data_info/marcha/shoulder_angles.png')
		if phase=='inc':
			plt.savefig(directory+'/data_info/incorporacion/shoulder_angles.png')
		if phase=='sent':
			plt.savefig(directory+'/data_info/silla/shoulder_angles.png')
	else:
		plt.show()
	plt.close()
	
def spine_angles(ktime,list_ang_tronco, frame_init, frame_end, directory,save_fig=False, phase='marcha'):
	ang=Smooth(pd.Series(list_ang_tronco[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	x=ktime[frame_init:frame_end]
	plt.figure(figsize=(16,5))
	plt.plot(x, ang)
	plt.grid(True)
	plt.xlabel('tiempo /s')
	plt.ylabel('Angulo columna /deg')
	plt.title('Angulo de la columna respecto a la vertical')
	if save_fig==True:
		if phase=='marcha':
			plt.savefig(directory+'/data_info/marcha/spine_angles.png')
		if phase=='inc':
			plt.savefig(directory+'/data_info/incorporacion/spine_angles.png')
		if phase=='sent':
			plt.savefig(directory+'/data_info/silla/spine_angles.png')
	else:
		plt.show()
	plt.close()
	
def spine_legs_angles(ktime,list_ang_pizq_col, list_ang_pdcha_col, frame_init, frame_end,directory, save_fig=False, phase='marcha'):
	angizq=Smooth(pd.Series(list_ang_pizq_col[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	angdcha=Smooth(pd.Series(list_ang_pdcha_col[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	x=ktime[frame_init:frame_end]
	plt.figure(figsize=(16,5))
	plt.plot(x, angizq, label='pierna_izq')
	plt.plot(x, angdcha, label='pierna_dcha')
	plt.grid(True)
	plt.legend()
	plt.xlabel('tiempo /s')
	plt.ylabel('Angulo columna-pierna /deg')
	plt.title('Angulo entre la columna y la pierna')
	if save_fig==True:
		if phase=='marcha':
			plt.savefig(directory+'/data_info/marcha/spine_legs_angles.png')
		if phase=='inc':
			plt.savefig(directory+'/data_info/incorporacion/spine_legs_angles.png')
		if phase=='sent':
			plt.savefig(directory+'/data_info/silla/spine_legs_angles.png')
	else:
		plt.show()
	plt.close()
	
def elbow_movement(ktime,ElbowLeft_Z,ElbowRight_Z,SpineMid_Z, frame_init,frame_end, dict_marcha,directory, save_fig=False):
	#elz=Smooth(pd.Series(ElbowLeft_Z[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	#erz=Smooth(pd.Series(ElbowRight_Z[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	#smz=Smooth(pd.Series(SpineMid_Z[frame_init:frame_end]).interpolate(method='polynomial', order=2).tolist(),10)
	elz=ElbowLeft_Z[frame_init:frame_end]
	erz=ElbowRight_Z[frame_init:frame_end]
	smz=SpineMid_Z[frame_init:frame_end]
	dif_izq=np.array(elz)-np.array(smz)
	dif_dcho=np.array(erz)-np.array(smz)
	
	dif_izq_abs=abs(dif_izq)
	dif_dcho_abs=abs(dif_dcho)
	
	dict_marcha['Distancia longitudinal media entre codo izquierdo y tronco  / m']=round(np.nanmean(dif_izq_abs),2)
	dict_marcha['Distancia longitudinal maxima entre codo izquierdo y tronco  / m']=round(np.nanmax(dif_izq_abs),2)
	dict_marcha['Distancia longitudinal media entre codo derecho y tronco  / m']=round(np.nanmean(dif_dcho_abs),2)
	dict_marcha['Distancia longitudinal maxima entre codo derecho y tronco  / m']=round(np.nanmax(dif_dcho_abs),2)
	
	plt.figure(figsize=(16,5))
	plt.plot(ktime[frame_init:frame_end],Smooth(dif_izq,6), label='brazo_izq')            
	plt.plot(ktime[frame_init:frame_end],Smooth(dif_dcho,6),label='brazo_dcho')
	plt.ylabel('Distancia entre codo y tronco / m')
	plt.xlabel('tiempo / s')
	plt.grid(True)
	plt.title('Movimiento oscilatorio de los brazos respecto al tronco')
	plt.legend()
	plt.axhline(y=0, color='black', linestyle='-')
	if save_fig==True:
		plt.savefig(directory+'/data_info/marcha/elbow_mov.png')
	else:
		plt.show()
	plt.close()
	
def chair_plot(frame_inc, frame_sentada,directory,save_fig=False):
	if os.path.exists(directory+'/weight.csv') is True:
		silla=pd.read_csv(directory+'/weight.csv')
		silla=silla[silla.columns[0]].tolist()
		silla=savgol_filter(silla,41,8)
		plt.figure(figsize=(16,5))
		plt.plot(silla)
		plt.xlabel('muestras')
		plt.ylabel('Peso /Kg')
		plt.grid(True)
		plt.title('Pesos silla')
		if save_fig==True:
			plt.savefig(directory+'/data_info/silla/chair_complet.png')
		else:
			plt.show()
		plt.close()
		
		ind=int(frame_inc*(8/3))+60
		plt.figure(figsize=(16,5))
		plt.plot(silla[0:ind])
		#plt.axvline(frame_inc_begin/30,color='k')
		plt.ylabel('Peso / Kg')
		plt.xlabel('n')
		plt.grid(True)
		plt.title('Silla Báscula')
		if save_fig==True:
			plt.savefig(directory+'/data_info/silla/chair_inc.png')
		else:
			plt.show()
		plt.close()
		
		ind=int(frame_sentada*(8/3))-60
		plt.figure(figsize=(16,5))
		x=(np.arange(silla[ind], len(silla[ind:]))+ind)/80
		plt.plot(silla[ind:])
		plt.ylabel('Peso / Kg')
		plt.xlabel('n')
		plt.grid(True)
		plt.title('Silla Báscula')
		if save_fig==True:
			plt.savefig(directory+'/data_info/silla/chair_sent.png')
		else:
			plt.show()
		plt.close()


import matplotlib.pyplot as plt
import numpy as np


def speed(SpineBase_Z, ktime, frame_inc, frame_change, directory,dict_marcha, plot=False, save_fig=False):     
	dist_recorrida_vel=[]
	l=[]
	dist_recorrida_vel2=[]
	l2=[]
	
	c=-1
	for i in SpineBase_Z[:frame_change]:
		c+=1  
		if i <=3 and i>=2:
			dist_recorrida_vel.append(i)
			l.append(c)
		if i <=3.3 and i>=1.8:
			dist_recorrida_vel2.append(i)
			l2.append(c)
					
	dist=dist_recorrida_vel[0]-dist_recorrida_vel[-1]
	t=ktime[l[-1]]-ktime[l[0]]
	vel_med1=dist/t

	dist2=dist_recorrida_vel2[0]-dist_recorrida_vel2[-1]
	t2=ktime[l2[-1]]-ktime[l2[0]]
	vel_med2=dist2/t2
	
	
	dict_marcha['Velocidad de la marcha  (medida entre 2 y 3 m) / m/s']= round(vel_med1,2)
	dict_marcha['Velocidad de la marcha  (medida entre 1.8 y 3.3 m) / m/s']= round(vel_med2,2)

	
	n=3
	slice_= lambda A, n=n: [A[i:i+n] for i in range(0, len(A), n)] #agrupa valores de una lista de n en n
	#slice_2= lambda A, n=2: [A[i:i+n] for i in range(0, len(A), n)]
	
	SpineBase_slice=slice_(SpineBase_Z[frame_inc+5:frame_change])
	ktime_slice=slice_(ktime[frame_inc+5:frame_change])
	
	dist_inst=[]
	for i in SpineBase_slice:
		if len(i)==n:
			dist_inst.append(np.abs(i[1]-i[0]))
	dist_plot=[]
	for i in SpineBase_slice:
		if len(i)==n:
			dist_plot.append(np.nanmean(i))

	time_inst=[]      
	for i in ktime_slice:
		if len(i)==n:
			time_inst.append(np.abs(i[1]-i[0]))   
	time_plot=[]      
	for i in ktime_slice:
		if len(i)==n:
			time_plot.append(np.nanmean(i))   
			
	vel_inst=np.array(dist_inst)/np.array(time_inst)
	
	vel_max=np.nanmax(vel_inst[vel_inst != np.inf])
	
	#if dicti==True:
	dict_marcha['Velocidad maxima / m/s']= round(vel_max,2)
		
	if plot==True:
		fig, axs = plt.subplots(2, 1,figsize=(16,5))
		axs[0].bar(dist_plot,vel_inst,color='red', edgecolor='black',width=0.05, align='center')
		axs[1].bar(time_plot,vel_inst,color='blue', edgecolor='black',width=0.05, align='center')
		axs[0].set_xlabel('Distancia a la Kinect (ida) /m')
		axs[0].set_ylabel('Velocidad instantánea  / m/s')
		axs[0].set_xlim(np.nanmax(dist_plot)+0.2,np.nanmin(dist_plot)-0.2)
		axs[1].set_xlim(np.nanmin(time_plot)-0.2,np.nanmax(time_plot)+0.2)
		axs[1].set_xlabel('Tiempo transcurrido (ida) /s')
		axs[1].set_ylabel('Velocidad instantánea  / m/s')
		axs[0].set_title('Velocidad Instantánea (ida) / m/s', fontsize=12)
		axs[1].set_axisbelow(True)
		axs[0].set_axisbelow(True)
		axs[1].grid(True)
		axs[0].grid(True)
		time_span_ind=[index for index, value in enumerate(np.array(dist_plot).astype(int)) if value == 2]
		time_span_ind2=[index for index, value in enumerate(np.array(dist_plot)) if (value <= 3.3 and value >=1.8)]
		axs[1].axvspan(time_plot[time_span_ind[0]],time_plot[time_span_ind[-1]],alpha=0.1,color='blue')
		axs[0].axvspan(dist_plot[time_span_ind[0]],dist_plot[time_span_ind[-1]],alpha=0.1,color='red')
		axs[1].axvspan(time_plot[time_span_ind2[0]],time_plot[time_span_ind2[-1]],alpha=0.1,color='blue')
		axs[0].axvspan(dist_plot[time_span_ind2[0]],dist_plot[time_span_ind2[-1]],alpha=0.1,color='red')
		fig.subplots_adjust(hspace=0.5)
		if save_fig==True:
			plt.savefig(directory+'/data_info/marcha/vel_inst.png')
		else:
			plt.show()
		plt.close()

	return(vel_med1,vel_med2,round(vel_max,2))


import cv2
import numpy as np
import pandas as pd
import bson
from .utils import frame_firstmax_lists
from .joint_angles import angulo_pierna, ang_pierna_tronco

def make_bsonlist(directory):
	#read video duration and frames.bson file which contains all information about the record
	v=cv2.VideoCapture(directory+'/video.mpeg')
	frameCount = int(v.get(cv2.CAP_PROP_FRAME_COUNT))

	bson_list=[]
	c=0
	bson_init = open(directory+'/frames.bson', 'rb')
	bson_r= bson_init.read()
	for i in np.arange(1,1+frameCount):
		bson_read = bson.decode_document(bson_r,c)
		bson_file=bson_read[1]
		c=bson_read[0]
		bson_list.append(bson_file)
	
	return(bson_list)
	

def kinect_time(bson_list):
	#generate a list with the time for each frame begins at t=0s
	real_time=[]
	ref_time=[]
	for i in range(len(bson_list)):
		l=bson_list[i]['RelativeTime'].split(':')
		#print('time',bson_list[i]['RelativeTime'])
		#print('time_split',l)
		real_time.append(float(l[2]))
		ref_time.append(float(l[1]))
	time=[] 
	real_time[0]=real_time[1]
	ref_time[0]=ref_time[1]
	c=0
	for i in real_time:
		time_dif=int(ref_time[c]-ref_time[0])
		time.append(i-real_time[0]+(60*time_dif))
		c+=1
	return(time)

def correct_TrackingId(bson_list):
	#identifies the correct person to evaluate if appears other people in the video.
	#This correct person is the first person that Kinect recognizes
	id_list=[]
	for bson_simple in bson_list:
		for i in bson_simple['BodiesEx']:
			if i['TrackingId']!=0:
				id_list.append(i['TrackingId'])
	return(list(set(id_list)))
    
	
def joints():
	for i in bson_list[7]['BodiesEx'][1]['Joints'].keys():
		for j in ['X','Y','Z']:
			globals()['{}_{}'.format(i,j)]=[]
			for k in bson_list:
				for m in k['BodiesEx']:
					if m['TrackingId']==id_num[0]:
						for joint in m['Joints'].keys():
							if joint==i:
								if m['Joints'][joint]['TrackingState']==2:
									globals()['{}_{}'.format(i,j)].append(m['Joints'][joint]['Position'][j])
								else:
									globals()['{}_{}'.format(i,j)].append(np.nan)
							else:pass
			globals()['{}_{}_arr'.format(i,j)]=np.asarray(globals()['{}_{}'.format(i,j)])
			
#def joints() must be executed as exec(inspect.getsource(data.joints)[15:]) 
#It generates lists and arrays with all positions for each joint. Ej: AnkleLeft_X, AnkleLeft_Y and AnkleLeft_Z
	
def frame_change(SpineBase_Z,WristRight_Z,WristLeft_Z): 
	#This is the frame in which the outward journey ends 
	for i in SpineBase_Z:
		ind=SpineBase_Z.index(i)
		if i<1:
			break
	if np.nanmin(WristRight_Z[:ind]) < np.nanmin(WristLeft_Z[:ind]):
		frame_change=(WristRight_Z.index(np.nanmin(WristRight_Z[:ind])))
	else:
		frame_change=(WristLeft_Z.index(np.nanmin(WristLeft_Z[:ind])))

	return(frame_change)		
	
def frame_incorporacion(list_ang_pdcha,list_ang_pizq,list_ang_pdcha_col,list_ang_pizq_col,frame_change):
	#This is the frame in which the rise ends 
	frame_inc1=frame_firstmax_lists(list_ang_pdcha[0:frame_change],list_ang_pizq[0:frame_change])
	frame_inc2=frame_firstmax_lists(list_ang_pdcha_col[0:frame_change],list_ang_pizq_col[0:frame_change])
	frame_inc=int((frame_inc1+frame_inc2)/2) #FRAME FINAL INCORPORACION
	return(frame_inc)

def frame_sentada(list_ang_pdcha,list_ang_pizq,list_ang_pdcha_col,list_ang_pizq_col,frame_change):
	#This is the frame in which the person begins to sit
	frame_sentada1=frame_firstmax_lists(list_ang_pdcha[:frame_change:-1],list_ang_pizq[:frame_change:-1])
	frame_sentada2=frame_firstmax_lists(list_ang_pdcha_col[:frame_change:-1],list_ang_pizq_col[:frame_change:-1])
	frame_sentada=len(list_ang_pdcha)-int((frame_sentada1+frame_sentada2)/2) #FRAME INICIO SENTADA
	return(frame_sentada)
	
def Sentada(HipLeft_X,HipRight_X,SpineBase_Z_arr,AnkleLeft_Z,AnkleRight_Z, ktime, frame_change, frame_sentada):
	#identifies the phase in which the person begins the turn to sit on the return
	data={'cad_izq':HipLeft_X[frame_change+30:frame_sentada],
		 'cad_dcha':HipRight_X[frame_change+30:frame_sentada]}
	df_cad=pd.DataFrame(data)
	df_cad.columns=['cad_izq','cad_dcha']
	df_cad['dis']=abs(df_cad['cad_izq'])+df_cad['cad_dcha']
	ind_cad=df_cad.loc[df_cad['dis']==np.nanmin(df_cad['dis'])].index
	frame_cad_min=ind_cad+frame_change+30
	frame_cad_min=frame_cad_min.tolist()
	frame_cad_min=int(frame_cad_min[0])
	dif_frames=frame_sentada-frame_cad_min
	frame_acomodo=frame_cad_min-dif_frames
	if SpineBase_Z_arr[frame_cad_min]<3.5:
		c=-1
		for i in SpineBase_Z_arr[frame_change+30:]:
			c+=1
			if i>3.5:
				frame_acomodo=c+frame_change+30
				break
	
	if AnkleLeft_Z[frame_acomodo]<AnkleRight_Z[frame_acomodo]:
		limit_now=AnkleLeft_Z[frame_cad_min]
		w=0
	else:
		limit_now=AnkleRight_Z[frame_cad_min]
		w=1
	duracion=ktime[frame_sentada]-ktime[frame_acomodo] 

	return(limit_now,frame_cad_min,w,frame_acomodo, duracion)

def NumPasosAc(AnkleLeft_X_arr,AnkleRight_X_arr,dict_silla):
	#number of steps in the turn just before starting to sit on the return
	alr=AnkleLeft_X_arr.round(2)
	c=0
	pasos=[]
	for i in alr:
		c+=1
		if c+5<=len(alr) and i == alr[c+4]:
			pasos.append(1)
		else:
			pasos.append(0)		
	arr=AnkleRight_X_arr.round(2)
	c=0
	for i in arr:
		c+=1
		if c+5<len(alr) and i == arr[c+4]:
			pasos.append(1)
		else:
			pasos.append(0)
	num_pasos=0
	c=1
	for i in pasos:
		if i==1 and pasos[c]==0:
			num_pasos+=1		
	if num_pasos<1:
		num_pasos=2
	
	dict_silla['Numero de pasos en el giro']=num_pasos
	return(num_pasos)
	
	



from setuptools import setup, find_packages

setup(name='pyktug-guilleeh90',
		version='0.0.1',
		description='Data analysis in TUG test for Kinect v2',
		license='MIT',
		author='Guillermo Díaz',
		author_email='guillermodiazsm@gmail.com',
		url='https://github.com/guilleeh90',
		packages=find_packages(),
		classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
		],
		python_requires='>=3.6',
		)



import numpy as np

def inclinacion_plano(frame_inc, frame_change, Neck_Z, Neck_Y,SpineBase_Z,SpineBase_Y,SpineMid_Z,SpineMid_Y, dict_tec):
	#busca la inclinación de la Kinect respecto al plano horizontal (suelo) mediante la variación
	#de la altura de varios puntos del cuerpo cuya altura es cuasiconstante durante la marcha
	x_neck=np.asarray(Neck_Z[frame_inc:frame_change], dtype='int32')
	p = np.polyfit(x_neck, Neck_Y[frame_inc:frame_change], 1)
	y_ajuste_neck = p[0]*x_neck + p[1]

	x_base=np.asarray(SpineBase_Z[frame_inc:frame_change], dtype='int32')
	p = np.polyfit(x_base, SpineBase_Y[frame_inc:frame_change], 1)
	y_ajuste_base = p[0]*x_base + p[1]


	x_mid=np.asarray(SpineMid_Z[frame_inc:frame_change], dtype='int32')
	p = np.polyfit(x_mid, SpineMid_Y[frame_inc:frame_change], 1)
	y_ajuste_mid = p[0]*x_mid + p[1]

	if (y_ajuste_base[0]>y_ajuste_base[-1] and y_ajuste_mid[0]>y_ajuste_mid[-1] and 
	y_ajuste_neck[0]>y_ajuste_neck[-1]):
		angle_neck = np.rad2deg(np.arctan2(y_ajuste_neck[0] - y_ajuste_neck[-1], x_neck[0] - x_neck[-1]))
		angle_base = np.rad2deg(np.arctan2(y_ajuste_base[0] - y_ajuste_base[-1], x_base[0] - x_base[-1]))
		angle_mid = np.rad2deg(np.arctan2(y_ajuste_mid[0] - y_ajuste_mid[-1], x_mid[0] - x_mid[-1]))

		angle=(angle_neck+angle_base+angle_mid)/3
		
		#dict_tec['Inclinacion plano horizontal (descendente) / grados']=round(angle,1)
		
		angle=angle*(-1)
		
	elif (y_ajuste_base[-1]>y_ajuste_base[0] and y_ajuste_mid[-1]>y_ajuste_mid[0] and 
	y_ajuste_neck[-1]>y_ajuste_neck[0]):
		angle_neck = np.rad2deg(np.arctan2(y_ajuste_neck[-1] - y_ajuste_neck[0], x_neck[-1] - x_neck[0]))
		angle_base = np.rad2deg(np.arctan2(y_ajuste_base[-1] - y_ajuste_base[0], x_base[-1] - x_base[0]))
		angle_mid = np.rad2deg(np.arctan2(y_ajuste_mid[-1] - y_ajuste_mid[0], x_mid[-1] - x_mid[0]))

		angle=180-(angle_neck+angle_base+angle_mid)/3
		
		
		#dict_tec['Inclinacion plano horizontal (ascendente) / grados']=round(angle,1)
	else:
		angle=0
		#dict_tec['Inclinacion plano horizontal / grados']=round(angle,1)
	
	dict_tec['Inclinacion plano horizontal / grados']=round(angle,1)

	return(angle)


import pandas as pd
import numpy as np
from .utils import Minimos
import os
import matplotlib.pyplot as plt

def fases_prueba(SpineBase_Z_arr,list_ang_pdcha_col,list_ang_pizq_col,ktime,frame_acomodo,frame_sentada,frame_inc, frame_inc_begin, directory, save_fig=False):
	#INCORPORACION
	
	if os.path.exists(directory+'\weight.csv') is True:
		frame_inc_begin=int(frame_inc_begin*3/8)
		fase_inc=ktime[frame_inc]-ktime[frame_inc_begin]
		
	else:
	  
		minimos_col_dcha=Minimos(list_ang_pdcha_col[0:frame_inc])
		minimos_col_izq=Minimos(list_ang_pizq_col[0:frame_inc])
		for i in minimos_col_dcha[::-1]:
			if list_ang_pdcha_col[i] <90:
				frame_inc_begin_dcha=i
		for i in minimos_col_izq[::-1]:
			if list_ang_pizq_col[i] <90:
				frame_inc_begin_izq=i
				
		frame_inc_begin=int((frame_inc_begin_izq+frame_inc_begin_dcha)/2)
		fase_inc=ktime[frame_inc]-ktime[frame_inc_begin]
		
		
	#MARCHA HACIA DELANTE Y GIRO 
	l=[]
	c=-1
	for i in SpineBase_Z_arr:
		c+=1
		if i<=1.4:
				l.append(c)
				
	fase_marcha_adelante=ktime[l[0]]-ktime[frame_inc]
	fase_giro1=ktime[l[-1]]-ktime[l[0]]
	
	#MARCHA HACIA ATRÁS
	fase_marcha_atras=ktime[frame_acomodo]-ktime[l[-1]]
	
	#SEGUNDO GIRO
	fase_giro2=ktime[frame_sentada]-ktime[frame_acomodo]
	
	#SENTADA
	
	minimos_sent_fin_dcha=Minimos(list_ang_pdcha_col[frame_sentada:])
	minimos_sent_fin_izq=Minimos(list_ang_pizq_col[frame_sentada:])

	for i in minimos_sent_fin_dcha:
		if list_ang_pdcha_col[frame_sentada:][i]<120:
			frame_sentada_fin_dcha=i
			break

	for i in minimos_sent_fin_izq:
		if list_ang_pizq_col[frame_sentada:][i]<120:
			frame_sentada_fin_izq=i
			break
	frame_sentada_fin=int((frame_sentada_fin_izq+frame_sentada_fin_dcha)/2)
	frame_sentada_fin=frame_sentada+frame_sentada_fin
	fase_sentarse=ktime[frame_sentada_fin]-ktime[frame_sentada]
	print('ktime sentada fin',ktime[frame_sentada_fin])
	tiempo_total=fase_inc+fase_marcha_adelante+fase_giro1+fase_marcha_atras+fase_giro2+fase_sentarse
	
	#FIGURA
	label1=(ktime[frame_inc_begin]+ktime[frame_inc])/2
	label2=(ktime[frame_inc]+ktime[l[0]])/2
	label3=(ktime[l[0]]+ktime[l[-1]])/2
	label4=(ktime[l[-1]]+ktime[frame_acomodo])/2
	label5=(ktime[frame_acomodo]+ktime[frame_sentada])/2
	label6=(ktime[frame_sentada]+ktime[frame_sentada_fin])/2
	alt_label=0.7
	
	if frame_inc_begin<frame_inc<l[0]<l[-1]<frame_acomodo<frame_sentada<frame_sentada_fin:
	
		plt.figure(figsize=(20,3))
		plt.plot(ktime,np.repeat(0,len(ktime)),'k')
		plt.axvline(ktime[frame_inc_begin],color='k',ls='--')
		plt.axvline(ktime[frame_inc],color='k',ls='--')
		plt.axvline(ktime[l[0]],color='k',ls='--')
		plt.axvline(ktime[l[-1]],color='k',ls='--')
		plt.axvline(ktime[frame_acomodo],color='k',ls='--')
		plt.axvline(ktime[frame_sentada],color='k',ls='--')
		plt.axvline(ktime[frame_sentada_fin],color='k',ls='--')
		plt.ylim(0,1)
		plt.yticks([])
		plt.title('FASES DE LA PRUEBA (Tiempo Total: {} s)'.format(round(tiempo_total,2)))
		plt.xlabel('tiempo /s')
		plt.text(label1,alt_label,'INCORPORACIÓN\n\n{}s'.format(round(fase_inc,2)),horizontalalignment='center',rotation=0)
		plt.text(label2,alt_label,'MARCHA\nADELANTE\n\n{}s'.format(round(fase_marcha_adelante,2)),horizontalalignment='center',rotation=0)
		plt.text(label3,alt_label,'GIRO\nMEDIO\n\n{}s'.format(round(fase_giro1,2)),horizontalalignment='center',rotation=0)
		plt.text(label4,alt_label,'MARCHA\nATRÁS\n\n{}s'.format(round(fase_marcha_atras,2)),horizontalalignment='center',rotation=0)
		plt.text(label5,alt_label,'GIRO\nFINAL\n\n{}s'.format(round(fase_giro2,2)),horizontalalignment='center',rotation=0)
		plt.text(label6,alt_label,'SENTADA\n\n{}s'.format(round(fase_sentarse,2)),horizontalalignment='center',rotation=0)
		plt.axvspan(ktime[frame_inc_begin],ktime[frame_inc],alpha=0.1,color='green')
		plt.axvspan(ktime[frame_inc],ktime[l[0]],alpha=0.1,color='red')
		plt.axvspan(ktime[l[0]],ktime[l[-1]],alpha=0.1,color='yellow')
		plt.axvspan(ktime[l[-1]],ktime[frame_acomodo],alpha=0.1,color='red')
		plt.axvspan(ktime[frame_acomodo],ktime[frame_sentada],alpha=0.1,color='yellow')
		plt.axvspan(ktime[frame_sentada],ktime[frame_sentada_fin],alpha=0.1,color='green')
		if save_fig==True:
			plt.savefig(directory+'/data_info/fases.png',bbox_inches = 'tight')
		else:
			plt.show()
		plt.close()
	else:
		pass

 